@@ -18,7 +18,7 @@ from typing import (
     overload,
 )
 
-from cached_property import cached_property  # type: ignore
+from backports.cached_property import cached_property
 from typing_extensions import Literal
 
 from strawberry.annotation import StrawberryAnnotation
@@ -40,6 +40,9 @@ if TYPE_CHECKING:
 _RESOLVER_TYPE = Union[StrawberryResolver, Callable, staticmethod, classmethod]
 
 
+UNRESOLVED = object()
+
+
 class StrawberryField(dataclasses.Field):
     python_name: str
 
@@ -67,7 +70,7 @@ class StrawberryField(dataclasses.Field):
         if sys.version_info >= (3, 10):
             kwargs["kw_only"] = False
 
-        super().__init__(  # type: ignore
+        super().__init__(
             default=(default if default is not UNSET else dataclasses.MISSING),
             default_factory=(
                 # mypy is not able to understand that default factory
@@ -132,7 +135,7 @@ class StrawberryField(dataclasses.Field):
                     "Union",
                 )
             elif getattr(argument.type, "_type_definition", False):
-                if argument.type._type_definition.is_interface:
+                if argument.type._type_definition.is_interface:  # type: ignore
                     raise InvalidFieldArgument(
                         resolver.name,
                         argument.python_name,
@@ -192,7 +195,7 @@ class StrawberryField(dataclasses.Field):
         _ = resolver.arguments
 
     @property  # type: ignore
-    def type(self) -> Union[StrawberryType, type]:  # type: ignore
+    def type(self) -> Union[StrawberryType, type, Literal[UNRESOLVED]]:  # type: ignore
         # We are catching NameError because dataclasses tries to fetch the type
         # of the field from the class before the class is fully defined.
         # This triggers a NameError error when using forward references because
@@ -212,7 +215,7 @@ class StrawberryField(dataclasses.Field):
 
             return self.type_annotation.resolve()
         except NameError:
-            return None  # type: ignore
+            return UNRESOLVED
 
     @type.setter
     def type(self, type_: Any) -> None:
@@ -269,7 +272,7 @@ class StrawberryField(dataclasses.Field):
             permission_classes=self.permission_classes,
             default=self.default_value,
             # ignored because of https://github.com/python/mypy/issues/6910
-            default_factory=self.default_factory,  # type: ignore[misc]
+            default_factory=self.default_factory,
             deprecation_reason=self.deprecation_reason,
         )
 
